/******************************************************************************
//                                                                           //
//  Project: Software Interface for DCD-2 Devices                            //
//                                                                           //
//  CGC Instruments, (c) 2009-2013, Version 1.00. All rights reserved.       //
//                                                                           //
//  Definition for DCD-2.DLL routines                                        //
//                                                                           //
******************************************************************************/

#ifndef __DCD2_H__
#define __DCD2_H__

#include <windows.h>

#include "math.h"

#ifdef __cplusplus
extern "C" {
#endif

/************************************************************************************************************************
*
* The LPT_I2C_Open from LPT-I2C.dll must be called before the first usage of other routines.
*
* The return values of the routines are the defines LPT_I2C_ERR_XXX from LPT-I2C.h.
*
************************************************************************************************************************/

WORD _export pascal DCD_2_Version(); /* Get the DCD-2 software version */


/* Communication */
int _export pascal DCD_2_Check (BYTE & Present); /* Check for presence of the DCD-2 device, if the device responds, return non-zero in Present */


/* Laser control */
int _export pascal DCD_2_SetLaserState (BYTE    Active); /* Set the laser state, laser is activated if Active is nonzero */
int _export pascal DCD_2_GetLaserState (BYTE  & Active); /* Get the laser state, laser is activated if Active is nonzero */

#define DCD_2_LDD_INT_MIN    1 /* Minimum laser intensity:   1% */
#define DCD_2_LDD_INT_MAX  100 /* Maximum laser intensity: 100% */
int _export pascal DCD_2_SetLaserIntensity (float   Intensity); /* Set the laser intensity in % */
int _export pascal DCD_2_GetLaserIntensity (float & Intensity); /* Get the laser intensity in % */

#define DCD_2_LDD_DC_MIN     1 /* Minimum laser duty cycle:  1% */
#define DCD_2_LDD_DC_MAX    99 /* Maximum laser duty cycle: 99% */
int _export pascal DCD_2_SetLaserDC (float   DutyCycle); /* Set the laser duty cycle in % */
int _export pascal DCD_2_GetLaserDC (float & DutyCycle); /* Get the laser duty cycle in % */

#define DCD_2_LDD_PH_MIN  -180 /* Minimum laser phase: -180 deg */
#define DCD_2_LDD_PH_MAX   180 /* Maximum laser phase: +180 deg */
int _export pascal DCD_2_SetLaserPhase (int   Phase); /* Set the laser phase in degrees */
int _export pascal DCD_2_GetLaserPhase (int & Phase); /* Get the laser phase in degrees */


/* Detector control */
#define DCD_2_DET_AMPL_MIN    1 /* Minimum detector amplification */
#define DCD_2_DET_AMPL_MAX  100 /* Maximum detector amplification */
int _export pascal DCD_2_SetDetectorAmplification (float   Amplification); /* Set the detector amplification */
int _export pascal DCD_2_GetDetectorAmplification (float & Amplification); /* Get the detector amplification */


/* Decoder control */
/* The parameters are Boolean values, i.e. they are true if their value is nonzero */
int _export pascal DCD_2_SetDecoderConfiguration (BYTE   DifferenceX, BYTE   DifferenceY, BYTE   NegativeX, BYTE   NegativeY); /* Set the decoder configuration */
int _export pascal DCD_2_GetDecoderConfiguration (BYTE & DifferenceX, BYTE & DifferenceY, BYTE & NegativeX, BYTE & NegativeY); /* Get the decoder configuration */


/* General information */
int _export pascal DCD_2_FW_Ver  (WORD & Version);        /* Get firmware version */
int _export pascal DCD_2_FW_Date (char * DateString);     /* Get firmware date, the buffer DateString should be 16 bytes long */
int _export pascal DCD_2_Prod_ID (char * Identification); /* Get product identification, the buffer DateString should be 81 bytes long */
int _export pascal DCD_2_Prod_No (DWORD & Number);        /* Get product number */


/* Housekeeping data */
int _export pascal DCD_2_Get5V   (float & Voltage    ); /* Get internal 5V supply voltage in Volt */
int _export pascal DCD_2_Get3V   (float & Voltage    ); /* Get internal 3V supply voltage in Volt */
int _export pascal DCD_2_GetTemp (float & Temperature); /* Get temperature in K */

int _export pascal DCD_2_GetClkCPU (float & Clock); /* Get the CPU clock in Hz */
int _export pascal DCD_2_GetClkPer (float & Clock); /* Get the peripheral clock in Hz */
int _export pascal DCD_2_GetClkADC (float & Clock); /* Get the ADC clock in Hz */
int _export pascal DCD_2_GetClkDAC (float & Clock); /* Get the DAC clock in Hz */
int _export pascal DCD_2_GetClkMem (float & Clock); /* Get the memory clock in Hz */


/* Various */
int _export pascal DCD_2_GetUptime (double & Uptime); /* Get the uptime in seconds */

#ifdef __cplusplus
}
#endif

#endif//__DCD2_H__
